package be.iminds.ilabt.jfed.restapi.dao;

import be.iminds.ilabt.jfed.restapi.json.SpeaksForCredential;
import be.iminds.ilabt.jfed.restapi.json.SpeaksForCredentialBuilder;
import be.iminds.ilabt.jfed.util.GeniUrn;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.equalTo;
import static org.hamcrest.Matchers.is;

/**
 * SpeaksForCredentialTestCollection
 */
public class SpeaksForCredentialTestCollection {
    private final List<SpeaksForCredentialBuilder> all;

    public SpeaksForCredentialTestCollection() {
        all = new ArrayList<SpeaksForCredentialBuilder>();

        GeniUrn speakerA = GeniUrn.createGeniUrnFromEncodedParts("example.org", "user", "speakA");
        GeniUrn speakerB = GeniUrn.createGeniUrnFromEncodedParts("example.org", "user", "speakB");
        GeniUrn speakingForC = GeniUrn.createGeniUrnFromEncodedParts("example.org", "user", "speakingForC");
        GeniUrn speakingForD = GeniUrn.createGeniUrnFromEncodedParts("example.org", "user", "speakingForD");

        Timestamp expire10min = TestClock.get().getOffsetMinutes(10);
        Timestamp expire1hour = TestClock.get().getOffsetMinutes(60);

        all.add(new SpeaksForCredentialBuilder().setSpeaker(speakerA).setSpeakingFor(speakingForC).setExpire(expire10min).setCredentialXml("fake credential for testing 0"));
        all.add(new SpeaksForCredentialBuilder().setSpeaker(speakerB).setSpeakingFor(speakingForD).setExpire(expire10min).setCredentialXml("fake credential for testing 1"));
        all.add(new SpeaksForCredentialBuilder().setSpeaker(speakerA).setSpeakingFor(speakingForC).setExpire(expire1hour).setCredentialXml("fake credential for testing 2"));
        all.add(new SpeaksForCredentialBuilder().setSpeaker(speakerA).setSpeakingFor(speakingForD).setExpire(expire1hour).setCredentialXml("fake credential for testing 3"));
    }

    public SpeaksForCredential getByIndex(int index) {
        return all.get(index).create();
    }

    public void assertSame(SpeaksForCredential actual, SpeaksForCredential expected) {
        assertThat("speaker differs", actual.getSpeaker(), is(equalTo(expected.getSpeaker())));
        assertThat("speaking_for differs", actual.getSpeakingFor(), is(equalTo(expected.getSpeakingFor())));
        assertThat("expire differs", actual.getExpire(), is(equalTo(expected.getExpire())));
        assertThat("credential differs", actual.getCredentialXml(), is(equalTo(expected.getCredentialXml())));
    }
}
